@@ -50,11 +50,23 @@ FAILEDOPERATION_DELETEUSERFAILED = 'FailedOperation.DeleteUserFailed'
 # 解绑安全组失败。
 FAILEDOPERATION_DISASSOCIATESECURITYGROUPSFAILED = 'FailedOperation.DisassociateSecurityGroupsFailed'
 
+# 拉取安全组详情失败。
+FAILEDOPERATION_GETSECURITYGROUPDETAILFAILED = 'FailedOperation.GetSecurityGroupDetailFailed'
+
+# 实例不可退费。
+FAILEDOPERATION_INSTANCECANNOTRETURN = 'FailedOperation.InstanceCanNotReturn'
+
+# 实例退费失败。
+FAILEDOPERATION_INSTANCERETURNFAILED = 'FailedOperation.InstanceReturnFailed'
+
 # 修改账号权限失败。
 FAILEDOPERATION_MODIFYRIGHTFAILED = 'FailedOperation.ModifyRightFailed'
 
-# 消息队列操作失败。
-FAILEDOPERATION_MSGQUEUEOPERATIONFAILED = 'FailedOperation.MsgQueueOperationFailed'
+# 修改账号配置失败。
+FAILEDOPERATION_MODIFYUSERCONFIGFAILED = 'FailedOperation.ModifyUserConfigFailed'
+
+# 隔离实例失败。
+FAILEDOPERATION_OSSISOLATEINSTANCEFAILED = 'FailedOperation.OssIsolateInstanceFailed'
 
 # 请求后端接口失败。
 FAILEDOPERATION_OSSOPERATIONFAILED = 'FailedOperation.OssOperationFailed'
@@ -71,9 +83,18 @@ FAILEDOPERATION_SGCHANGEVIP = 'FailedOperation.SGChangeVip'
 # 设置规则失败。
 FAILEDOPERATION_SETRULELOCATIONFAILED = 'FailedOperation.SetRuleLocationFailed'
 
+# 安全组规则下发失败。
+FAILEDOPERATION_SETSVCLOCATIONFAILED = 'FailedOperation.SetSvcLocationFailed'
+
 # 标签键值校验或鉴权失败。
 FAILEDOPERATION_TAGDRYRUNERROR = 'FailedOperation.TagDryRunError'
 
+# 标签配额不足。
+FAILEDOPERATION_TAGQUOTAEXCEEDLIMIT = 'FailedOperation.TagQuotaExceedLimit'
+
+# 计费配置查询失败
+FAILEDOPERATION_TRADECONFIGNOTFOUND = 'FailedOperation.TradeConfigNotFound'
+
 # 实例安全组信息更新失败。
 FAILEDOPERATION_UPDATEINSTANCEINFOFAILED = 'FailedOperation.UpdateInstanceInfoFailed'
 
@@ -107,6 +128,12 @@ INTERNALERROR_COSCONFIGURATION = 'InternalError.CosConfiguration'
 # 备份文件签名失败。
 INTERNALERROR_COSSIGNURL = 'InternalError.CosSignUrl'
 
+# 创建流程失败。
+INTERNALERROR_CREATEFLOWERROR = 'InternalError.CreateFlowError'
+
+# 创建任务流程失败。
+INTERNALERROR_CREATEFLOWFAILED = 'InternalError.CreateFlowFailed'
+
 # DB影响行数为0错误。
 INTERNALERROR_DBROWSAFFECTEDERROR = 'InternalError.DBRowsAffectedError'
 
@@ -194,6 +221,9 @@ INTERNALERROR_QUERYPRICEFAILED = 'InternalError.QueryPriceFailed'
 # 操作读DB数据错误。
 INTERNALERROR_READDATABASEFAILED = 'InternalError.ReadDatabaseFailed'
 
+# 回档的时间不合法。
+INTERNALERROR_RETREATETIME = 'InternalError.RetreateTime'
+
 # 路由未发现。
 INTERNALERROR_ROUTENOTFOUND = 'InternalError.RouteNotFound'
 
@@ -296,6 +326,9 @@ INVALIDPARAMETERVALUE_ILLEGALRIGHTPARAM = 'InvalidParameterValue.IllegalRightPar
 # 找不到指定的可用区。
 INVALIDPARAMETERVALUE_ILLEGALZONE = 'InvalidParameterValue.IllegalZone'
 
+# 参数值传入错误。
+INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUEERROR = 'InvalidParameterValue.InvalidParameterValueError'
+
 # 分片不存在。
 INVALIDPARAMETERVALUE_SHARDNOTEXIST = 'InvalidParameterValue.ShardNotExist'
 
@@ -305,9 +338,18 @@ INVALIDPARAMETERVALUE_SPECIDILLEGAL = 'InvalidParameterValue.SpecIdIllegal'
 # 系统用户不允许操作。
 INVALIDPARAMETERVALUE_SUPERUSERFORBIDDEN = 'InvalidParameterValue.SuperUserForbidden'
 
+# 当前部署方式不允许设置此同步模式。
+INVALIDPARAMETERVALUE_SYNCMODENOTALLOWED = 'InvalidParameterValue.SyncModeNotAllowed'
+
 # 请求过于频繁。
 LIMITEXCEEDED_TOOFREQUENTLYCALLED = 'LimitExceeded.TooFrequentlyCalled'
 
+# 临时实例已经存在了。
+RESOURCEINUSE_TEMPINSTANCEEXIST = 'ResourceInUse.TempInstanceExist'
+
+# 资源不足。
+RESOURCEINSUFFICIENT = 'ResourceInsufficient'
+
 # 指定的账号不存在。
 RESOURCENOTFOUND_ACCOUNTDOESNOTEXIST = 'ResourceNotFound.AccountDoesNotExist'
 
@@ -326,6 +368,9 @@ RESOURCEUNAVAILABLE_BADINSTANCESTATUS = 'ResourceUnavailable.BadInstanceStatus'
 # COS API调用错误。
 RESOURCEUNAVAILABLE_COSAPIFAILED = 'ResourceUnavailable.CosApiFailed'
 
+# 独享集群状态异常。
+RESOURCEUNAVAILABLE_EXCLUSTERSTATUSABNORMAL = 'ResourceUnavailable.ExclusterStatusAbnormal'
+
 # 数据库实例已被删除。
 RESOURCEUNAVAILABLE_INSTANCEALREADYDELETED = 'ResourceUnavailable.InstanceAlreadyDeleted'
 
@@ -335,9 +380,15 @@ RESOURCEUNAVAILABLE_INSTANCEHASBEENLOCKED = 'ResourceUnavailable.InstanceHasBeen
 # 数据库实例状态不正确，当前无法操作。
 RESOURCEUNAVAILABLE_INSTANCESTATUSABNORMAL = 'ResourceUnavailable.InstanceStatusAbnormal'
 
+# 安全组校验失败。
+RESOURCEUNAVAILABLE_SGCHECKFAIL = 'ResourceUnavailable.SGCheckFail'
+
 # 没有权限操作该接口或资源。
 UNAUTHORIZEDOPERATION_PERMISSIONDENIED = 'UnauthorizedOperation.PermissionDenied'
 
+# 不支持该数据库版本。
+UNSUPPORTEDOPERATION_DBVERSIONNOTSUPPORTED = 'UnsupportedOperation.DbVersionNotSupported'
+
 # 不支持的无效操作。
 UNSUPPORTEDOPERATION_INVALIDOPERATION = 'UnsupportedOperation.InvalidOperation'
 
